Stan Math Library: Namespace List

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

Namespace List
Here is a list of all namespaces with brief descriptions:
[detail level 123]

▼N boost | Reimplementing boost functionality
N math | Reimplmeneting boost functionality for `stan::math::var` and and bugs in classification of integer types
▼N Eigen | (Expert) Numerical traits for algorithmic differentiation variables
N internal | (Expert) Product traits for algorithmic differentiation variables
▼N stan |
▼N math | Matrices and templated mathematical functions
N detail |
N std |

[ Stan Home Page ] © 2011–2016, Stan Development Team.